@@ -177,7 +177,7 @@ class Worker:
                         self._redis_opts[OPTS_REDIS_URL], timeout=5
                     )
                     if self._redis_opts.get(OPTS_REDIS_NAME) is not None:
-                        self._redis.client_setname(
+                        await self._redis.client_setname(
                             f"{self._redis_opts.get(OPTS_REDIS_NAME)}-{self._uuid}"
                         )
                     logger.warning("Redis connected")
@@ -393,7 +393,9 @@ class Worker:
         else:
             asyncio.ensure_future(coro)
 
-    async def send_result(self, result, context=None, result_channel=None):
+    async def send_result(
+        self, result, context=None, result_channel=None, wait_for_sqs=True
+    ):
         context_topic = None
         result_data = json.dumps(result)
 
@@ -445,13 +447,15 @@ class Worker:
                     )
 
             if context.get(CONTEXT_SQS_URL):
-                await self.send_sqs_message(context.get(CONTEXT_SQS_URL), result_data)
+                await self.send_sqs_message(
+                    context.get(CONTEXT_SQS_URL), result_data, wait=wait_for_sqs
+                )
 
         # always check the result_channel as it is usually used for data persistence
         if result_channel:
             for rc in result_channel.split(","):
                 if rc.startswith("https://sqs"):
-                    await self.send_sqs_message(rc, result_data)
+                    await self.send_sqs_message(rc, result_data, wait=wait_for_sqs)
                 elif rc.startswith("redis://"):
                     channel = rc.split("redis://")[1]
                     await self._redis.rpush(channel, result_data)
